.. autoarchive.rst
.. 
.. Project: AutoArchive
.. License: GNU GPLv3
.. 
.. Copyright (C) 2003 - 2015 Róbert Čerňanský



.. A section for the AutoArchive package.



AutoArchive
===========

.. automodule:: AutoArchive
   :no-members:



Sub-Packages
------------

.. toctree::
   :maxdepth: 1

   application
   infrastructure
   services
   ui



Modules
-------

starter
^^^^^^^

.. automodule:: AutoArchive.starter



_meta
^^^^^

.. automodule:: AutoArchive._meta
.. autoclass:: _Meta
